# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict

from alibabacloud_starrocks20221019 import models as main_models
from alibabacloud_tea_openapi import utils_models as open_api_util_models
from alibabacloud_tea_openapi.client import Client as OpenApiClient
from alibabacloud_tea_openapi.utils import Utils
from darabonba.core import DaraCore as DaraCore
from darabonba.runtime import RuntimeOptions

"""
"""
class Client(OpenApiClient):

    def __init__(
        self,
        config: open_api_util_models.Config,
    ):
        super().__init__(config)
        self._endpoint_rule = ''
        self.check_config(config)
        self._endpoint = self.get_endpoint('starrocks', self._region_id, self._endpoint_rule, self._network, self._suffix, self._endpoint_map, self._endpoint)

    def get_endpoint(
        self,
        product_id: str,
        region_id: str,
        endpoint_rule: str,
        network: str,
        suffix: str,
        endpoint_map: Dict[str, str],
        endpoint: str,
    ) -> str:
        if not DaraCore.is_null(endpoint):
            return endpoint
        if not DaraCore.is_null(endpoint_map) and not DaraCore.is_null(endpoint_map.get(region_id)):
            return endpoint_map.get(region_id)
        return Utils.get_endpoint_rules(product_id, region_id, endpoint_rule, network, suffix)

    def add_gateway_with_options(
        self,
        request: main_models.AddGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.AddGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fe_node_number):
            query['FeNodeNumber'] = request.fe_node_number
        if not DaraCore.is_null(request.gateway_name):
            query['GatewayName'] = request.gateway_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'AddGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/add',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.AddGatewayResponse(),
            self.call_api(params, req, runtime)
        )

    async def add_gateway_with_options_async(
        self,
        request: main_models.AddGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.AddGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fe_node_number):
            query['FeNodeNumber'] = request.fe_node_number
        if not DaraCore.is_null(request.gateway_name):
            query['GatewayName'] = request.gateway_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'AddGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/add',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.AddGatewayResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def add_gateway(
        self,
        request: main_models.AddGatewayRequest,
    ) -> main_models.AddGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.add_gateway_with_options(request, headers, runtime)

    async def add_gateway_async(
        self,
        request: main_models.AddGatewayRequest,
    ) -> main_models.AddGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.add_gateway_with_options_async(request, headers, runtime)

    def change_resource_group_with_options(
        self,
        request: main_models.ChangeResourceGroupRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ChangeResourceGroupResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.new_resource_group_id):
            query['NewResourceGroupId'] = request.new_resource_group_id
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_type):
            query['ResourceType'] = request.resource_type
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ChangeResourceGroup',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceGroup/change',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ChangeResourceGroupResponse(),
            self.call_api(params, req, runtime)
        )

    async def change_resource_group_with_options_async(
        self,
        request: main_models.ChangeResourceGroupRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ChangeResourceGroupResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.new_resource_group_id):
            query['NewResourceGroupId'] = request.new_resource_group_id
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_type):
            query['ResourceType'] = request.resource_type
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ChangeResourceGroup',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceGroup/change',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ChangeResourceGroupResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def change_resource_group(
        self,
        request: main_models.ChangeResourceGroupRequest,
    ) -> main_models.ChangeResourceGroupResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.change_resource_group_with_options(request, headers, runtime)

    async def change_resource_group_async(
        self,
        request: main_models.ChangeResourceGroupRequest,
    ) -> main_models.ChangeResourceGroupResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.change_resource_group_with_options_async(request, headers, runtime)

    def create_instance_v1with_options(
        self,
        request: main_models.CreateInstanceV1Request,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.CreateInstanceV1Response:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.admin_password):
            body['AdminPassword'] = request.admin_password
        if not DaraCore.is_null(request.agent_node_group):
            body['AgentNodeGroup'] = request.agent_node_group
        if not DaraCore.is_null(request.auto_pay):
            body['AutoPay'] = request.auto_pay
        if not DaraCore.is_null(request.auto_renew):
            body['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.backend_node_groups):
            body['BackendNodeGroups'] = request.backend_node_groups
        if not DaraCore.is_null(request.client_token):
            body['ClientToken'] = request.client_token
        if not DaraCore.is_null(request.dlf_catalog_name):
            body['DlfCatalogName'] = request.dlf_catalog_name
        if not DaraCore.is_null(request.dlf_catalog_type):
            body['DlfCatalogType'] = request.dlf_catalog_type
        if not DaraCore.is_null(request.duration):
            body['Duration'] = request.duration
        if not DaraCore.is_null(request.encrypted):
            body['Encrypted'] = request.encrypted
        if not DaraCore.is_null(request.frontend_node_groups):
            body['FrontendNodeGroups'] = request.frontend_node_groups
        if not DaraCore.is_null(request.gateway_type):
            body['GatewayType'] = request.gateway_type
        if not DaraCore.is_null(request.instance_name):
            body['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.kms_key_id):
            body['KmsKeyId'] = request.kms_key_id
        if not DaraCore.is_null(request.linked_ram_user_name):
            body['LinkedRamUserName'] = request.linked_ram_user_name
        if not DaraCore.is_null(request.observer_node_groups):
            body['ObserverNodeGroups'] = request.observer_node_groups
        if not DaraCore.is_null(request.oss_accessing_role_name):
            body['OssAccessingRoleName'] = request.oss_accessing_role_name
        if not DaraCore.is_null(request.package_type):
            body['PackageType'] = request.package_type
        if not DaraCore.is_null(request.pay_type):
            body['PayType'] = request.pay_type
        if not DaraCore.is_null(request.pricing_cycle):
            body['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.principal_type):
            body['PrincipalType'] = request.principal_type
        if not DaraCore.is_null(request.promotion_option_no):
            body['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.ram_user_id):
            body['RamUserId'] = request.ram_user_id
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            body['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.run_mode):
            body['RunMode'] = request.run_mode
        if not DaraCore.is_null(request.tags):
            body['Tags'] = request.tags
        if not DaraCore.is_null(request.v_switches):
            body['VSwitches'] = request.v_switches
        if not DaraCore.is_null(request.version):
            body['Version'] = request.version
        if not DaraCore.is_null(request.vpc_id):
            body['VpcId'] = request.vpc_id
        if not DaraCore.is_null(request.zone_id):
            body['ZoneId'] = request.zone_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'CreateInstanceV1',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/createV1',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateInstanceV1Response(),
            self.call_api(params, req, runtime)
        )

    async def create_instance_v1with_options_async(
        self,
        request: main_models.CreateInstanceV1Request,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.CreateInstanceV1Response:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.admin_password):
            body['AdminPassword'] = request.admin_password
        if not DaraCore.is_null(request.agent_node_group):
            body['AgentNodeGroup'] = request.agent_node_group
        if not DaraCore.is_null(request.auto_pay):
            body['AutoPay'] = request.auto_pay
        if not DaraCore.is_null(request.auto_renew):
            body['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.backend_node_groups):
            body['BackendNodeGroups'] = request.backend_node_groups
        if not DaraCore.is_null(request.client_token):
            body['ClientToken'] = request.client_token
        if not DaraCore.is_null(request.dlf_catalog_name):
            body['DlfCatalogName'] = request.dlf_catalog_name
        if not DaraCore.is_null(request.dlf_catalog_type):
            body['DlfCatalogType'] = request.dlf_catalog_type
        if not DaraCore.is_null(request.duration):
            body['Duration'] = request.duration
        if not DaraCore.is_null(request.encrypted):
            body['Encrypted'] = request.encrypted
        if not DaraCore.is_null(request.frontend_node_groups):
            body['FrontendNodeGroups'] = request.frontend_node_groups
        if not DaraCore.is_null(request.gateway_type):
            body['GatewayType'] = request.gateway_type
        if not DaraCore.is_null(request.instance_name):
            body['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.kms_key_id):
            body['KmsKeyId'] = request.kms_key_id
        if not DaraCore.is_null(request.linked_ram_user_name):
            body['LinkedRamUserName'] = request.linked_ram_user_name
        if not DaraCore.is_null(request.observer_node_groups):
            body['ObserverNodeGroups'] = request.observer_node_groups
        if not DaraCore.is_null(request.oss_accessing_role_name):
            body['OssAccessingRoleName'] = request.oss_accessing_role_name
        if not DaraCore.is_null(request.package_type):
            body['PackageType'] = request.package_type
        if not DaraCore.is_null(request.pay_type):
            body['PayType'] = request.pay_type
        if not DaraCore.is_null(request.pricing_cycle):
            body['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.principal_type):
            body['PrincipalType'] = request.principal_type
        if not DaraCore.is_null(request.promotion_option_no):
            body['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.ram_user_id):
            body['RamUserId'] = request.ram_user_id
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            body['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.run_mode):
            body['RunMode'] = request.run_mode
        if not DaraCore.is_null(request.tags):
            body['Tags'] = request.tags
        if not DaraCore.is_null(request.v_switches):
            body['VSwitches'] = request.v_switches
        if not DaraCore.is_null(request.version):
            body['Version'] = request.version
        if not DaraCore.is_null(request.vpc_id):
            body['VpcId'] = request.vpc_id
        if not DaraCore.is_null(request.zone_id):
            body['ZoneId'] = request.zone_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'CreateInstanceV1',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/createV1',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateInstanceV1Response(),
            await self.call_api_async(params, req, runtime)
        )

    def create_instance_v1(
        self,
        request: main_models.CreateInstanceV1Request,
    ) -> main_models.CreateInstanceV1Response:
        runtime = RuntimeOptions()
        headers = {}
        return self.create_instance_v1with_options(request, headers, runtime)

    async def create_instance_v1_async(
        self,
        request: main_models.CreateInstanceV1Request,
    ) -> main_models.CreateInstanceV1Response:
        runtime = RuntimeOptions()
        headers = {}
        return await self.create_instance_v1with_options_async(request, headers, runtime)

    def create_service_linked_role_with_options(
        self,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.CreateServiceLinkedRoleResponse:
        req = open_api_util_models.OpenApiRequest(
            headers = headers
        )
        params = open_api_util_models.Params(
            action = 'CreateServiceLinkedRole',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/user/create_default_role',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateServiceLinkedRoleResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_service_linked_role_with_options_async(
        self,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.CreateServiceLinkedRoleResponse:
        req = open_api_util_models.OpenApiRequest(
            headers = headers
        )
        params = open_api_util_models.Params(
            action = 'CreateServiceLinkedRole',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/user/create_default_role',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.CreateServiceLinkedRoleResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_service_linked_role(self) -> main_models.CreateServiceLinkedRoleResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.create_service_linked_role_with_options(headers, runtime)

    async def create_service_linked_role_async(self) -> main_models.CreateServiceLinkedRoleResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.create_service_linked_role_with_options_async(headers, runtime)

    def delete_gateway_with_options(
        self,
        request: main_models.DeleteGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DeleteGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeleteGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/delete',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeleteGatewayResponse(),
            self.call_api(params, req, runtime)
        )

    async def delete_gateway_with_options_async(
        self,
        request: main_models.DeleteGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DeleteGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DeleteGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/delete',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DeleteGatewayResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def delete_gateway(
        self,
        request: main_models.DeleteGatewayRequest,
    ) -> main_models.DeleteGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.delete_gateway_with_options(request, headers, runtime)

    async def delete_gateway_async(
        self,
        request: main_models.DeleteGatewayRequest,
    ) -> main_models.DeleteGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.delete_gateway_with_options_async(request, headers, runtime)

    def describe_instances_with_options(
        self,
        tmp_req: main_models.DescribeInstancesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DescribeInstancesResponse:
        tmp_req.validate()
        request = main_models.DescribeInstancesShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.tag):
            request.tag_shrink = Utils.array_to_string_with_specified_style(tmp_req.tag, 'Tag', 'json')
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.instance_name):
            query['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.instance_status):
            query['InstanceStatus'] = request.instance_status
        if not DaraCore.is_null(request.page_number):
            query['PageNumber'] = request.page_number
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            query['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.tag_shrink):
            query['Tag'] = request.tag_shrink
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeInstances',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/describeInstances',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeInstancesResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_instances_with_options_async(
        self,
        tmp_req: main_models.DescribeInstancesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DescribeInstancesResponse:
        tmp_req.validate()
        request = main_models.DescribeInstancesShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.tag):
            request.tag_shrink = Utils.array_to_string_with_specified_style(tmp_req.tag, 'Tag', 'json')
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.instance_name):
            query['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.instance_status):
            query['InstanceStatus'] = request.instance_status
        if not DaraCore.is_null(request.page_number):
            query['PageNumber'] = request.page_number
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            query['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.tag_shrink):
            query['Tag'] = request.tag_shrink
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DescribeInstances',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/describeInstances',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeInstancesResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_instances(
        self,
        request: main_models.DescribeInstancesRequest,
    ) -> main_models.DescribeInstancesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.describe_instances_with_options(request, headers, runtime)

    async def describe_instances_async(
        self,
        request: main_models.DescribeInstancesRequest,
    ) -> main_models.DescribeInstancesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.describe_instances_with_options_async(request, headers, runtime)

    def describe_node_groups_with_options(
        self,
        request: main_models.DescribeNodeGroupsRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DescribeNodeGroupsResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.cluster_id):
            query['ClusterId'] = request.cluster_id
        if not DaraCore.is_null(request.page_number):
            query['PageNumber'] = request.page_number
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        body = {}
        if not DaraCore.is_null(request.component_type):
            body['componentType'] = request.component_type
        if not DaraCore.is_null(request.instance_id):
            body['instanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_ids):
            body['nodeGroupIds'] = request.node_group_ids
        if not DaraCore.is_null(request.node_group_name):
            body['nodeGroupName'] = request.node_group_name
        if not DaraCore.is_null(request.status):
            body['status'] = request.status
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'DescribeNodeGroups',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/nodegroup/describeNodeGroups',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeNodeGroupsResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_node_groups_with_options_async(
        self,
        request: main_models.DescribeNodeGroupsRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DescribeNodeGroupsResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.cluster_id):
            query['ClusterId'] = request.cluster_id
        if not DaraCore.is_null(request.page_number):
            query['PageNumber'] = request.page_number
        if not DaraCore.is_null(request.page_size):
            query['PageSize'] = request.page_size
        body = {}
        if not DaraCore.is_null(request.component_type):
            body['componentType'] = request.component_type
        if not DaraCore.is_null(request.instance_id):
            body['instanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_ids):
            body['nodeGroupIds'] = request.node_group_ids
        if not DaraCore.is_null(request.node_group_name):
            body['nodeGroupName'] = request.node_group_name
        if not DaraCore.is_null(request.status):
            body['status'] = request.status
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'DescribeNodeGroups',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/nodegroup/describeNodeGroups',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DescribeNodeGroupsResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_node_groups(
        self,
        request: main_models.DescribeNodeGroupsRequest,
    ) -> main_models.DescribeNodeGroupsResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.describe_node_groups_with_options(request, headers, runtime)

    async def describe_node_groups_async(
        self,
        request: main_models.DescribeNodeGroupsRequest,
    ) -> main_models.DescribeNodeGroupsResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.describe_node_groups_with_options_async(request, headers, runtime)

    def disable_sslconnection_with_options(
        self,
        request: main_models.DisableSSLConnectionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DisableSSLConnectionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DisableSSLConnection',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/disableSSLConnection',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DisableSSLConnectionResponse(),
            self.call_api(params, req, runtime)
        )

    async def disable_sslconnection_with_options_async(
        self,
        request: main_models.DisableSSLConnectionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.DisableSSLConnectionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'DisableSSLConnection',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/disableSSLConnection',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.DisableSSLConnectionResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def disable_sslconnection(
        self,
        request: main_models.DisableSSLConnectionRequest,
    ) -> main_models.DisableSSLConnectionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.disable_sslconnection_with_options(request, headers, runtime)

    async def disable_sslconnection_async(
        self,
        request: main_models.DisableSSLConnectionRequest,
    ) -> main_models.DisableSSLConnectionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.disable_sslconnection_with_options_async(request, headers, runtime)

    def enable_sslconnection_with_options(
        self,
        request: main_models.EnableSSLConnectionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.EnableSSLConnectionResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.custom_sslcertificate):
            body['CustomSSLCertificate'] = request.custom_sslcertificate
        if not DaraCore.is_null(request.enable_custom):
            body['EnableCustom'] = request.enable_custom
        if not DaraCore.is_null(request.instance_id):
            body['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.renewal):
            body['Renewal'] = request.renewal
        if not DaraCore.is_null(request.ssl_key_password):
            body['SslKeyPassword'] = request.ssl_key_password
        if not DaraCore.is_null(request.ssl_keystore_password):
            body['SslKeystorePassword'] = request.ssl_keystore_password
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'EnableSSLConnection',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/enableSSLConnection',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.EnableSSLConnectionResponse(),
            self.call_api(params, req, runtime)
        )

    async def enable_sslconnection_with_options_async(
        self,
        request: main_models.EnableSSLConnectionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.EnableSSLConnectionResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.custom_sslcertificate):
            body['CustomSSLCertificate'] = request.custom_sslcertificate
        if not DaraCore.is_null(request.enable_custom):
            body['EnableCustom'] = request.enable_custom
        if not DaraCore.is_null(request.instance_id):
            body['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.renewal):
            body['Renewal'] = request.renewal
        if not DaraCore.is_null(request.ssl_key_password):
            body['SslKeyPassword'] = request.ssl_key_password
        if not DaraCore.is_null(request.ssl_keystore_password):
            body['SslKeystorePassword'] = request.ssl_keystore_password
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'EnableSSLConnection',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/enableSSLConnection',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.EnableSSLConnectionResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def enable_sslconnection(
        self,
        request: main_models.EnableSSLConnectionRequest,
    ) -> main_models.EnableSSLConnectionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.enable_sslconnection_with_options(request, headers, runtime)

    async def enable_sslconnection_async(
        self,
        request: main_models.EnableSSLConnectionRequest,
    ) -> main_models.EnableSSLConnectionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.enable_sslconnection_with_options_async(request, headers, runtime)

    def get_instance_feature_gate_with_options(
        self,
        request: main_models.GetInstanceFeatureGateRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.GetInstanceFeatureGateResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetInstanceFeatureGate',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/features/featureGate',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetInstanceFeatureGateResponse(),
            self.call_api(params, req, runtime)
        )

    async def get_instance_feature_gate_with_options_async(
        self,
        request: main_models.GetInstanceFeatureGateRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.GetInstanceFeatureGateResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'GetInstanceFeatureGate',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/features/featureGate',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.GetInstanceFeatureGateResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def get_instance_feature_gate(
        self,
        request: main_models.GetInstanceFeatureGateRequest,
    ) -> main_models.GetInstanceFeatureGateResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.get_instance_feature_gate_with_options(request, headers, runtime)

    async def get_instance_feature_gate_async(
        self,
        request: main_models.GetInstanceFeatureGateRequest,
    ) -> main_models.GetInstanceFeatureGateResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.get_instance_feature_gate_with_options_async(request, headers, runtime)

    def isolate_leader_with_options(
        self,
        request: main_models.IsolateLeaderRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.IsolateLeaderResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.isolate_leader):
            query['IsolateLeader'] = request.isolate_leader
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'IsolateLeader',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/isolateLeader',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.IsolateLeaderResponse(),
            self.call_api(params, req, runtime)
        )

    async def isolate_leader_with_options_async(
        self,
        request: main_models.IsolateLeaderRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.IsolateLeaderResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.isolate_leader):
            query['IsolateLeader'] = request.isolate_leader
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'IsolateLeader',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/isolateLeader',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.IsolateLeaderResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def isolate_leader(
        self,
        request: main_models.IsolateLeaderRequest,
    ) -> main_models.IsolateLeaderResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.isolate_leader_with_options(request, headers, runtime)

    async def isolate_leader_async(
        self,
        request: main_models.IsolateLeaderRequest,
    ) -> main_models.IsolateLeaderResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.isolate_leader_with_options_async(request, headers, runtime)

    def list_gateway_with_options(
        self,
        request: main_models.ListGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ListGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ListGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/list',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ListGatewayResponse(),
            self.call_api(params, req, runtime)
        )

    async def list_gateway_with_options_async(
        self,
        request: main_models.ListGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ListGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ListGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/list',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ListGatewayResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def list_gateway(
        self,
        request: main_models.ListGatewayRequest,
    ) -> main_models.ListGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.list_gateway_with_options(request, headers, runtime)

    async def list_gateway_async(
        self,
        request: main_models.ListGatewayRequest,
    ) -> main_models.ListGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.list_gateway_with_options_async(request, headers, runtime)

    def modify_charge_type_with_options(
        self,
        request: main_models.ModifyChargeTypeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyChargeTypeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auto_renew):
            query['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.billing_instance_ids):
            query['BillingInstanceIds'] = request.billing_instance_ids
        if not DaraCore.is_null(request.duration):
            query['Duration'] = request.duration
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.pricing_cycle):
            query['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyChargeType',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/modifyChargeType',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyChargeTypeResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_charge_type_with_options_async(
        self,
        request: main_models.ModifyChargeTypeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyChargeTypeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.auto_renew):
            query['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.billing_instance_ids):
            query['BillingInstanceIds'] = request.billing_instance_ids
        if not DaraCore.is_null(request.duration):
            query['Duration'] = request.duration
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.pricing_cycle):
            query['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyChargeType',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/modifyChargeType',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyChargeTypeResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_charge_type(
        self,
        request: main_models.ModifyChargeTypeRequest,
    ) -> main_models.ModifyChargeTypeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_charge_type_with_options(request, headers, runtime)

    async def modify_charge_type_async(
        self,
        request: main_models.ModifyChargeTypeRequest,
    ) -> main_models.ModifyChargeTypeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_charge_type_with_options_async(request, headers, runtime)

    def modify_cu_with_options(
        self,
        request: main_models.ModifyCuRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyCuResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyCu',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyCu',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyCuResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_cu_with_options_async(
        self,
        request: main_models.ModifyCuRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyCuResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyCu',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyCu',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyCuResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_cu(
        self,
        request: main_models.ModifyCuRequest,
    ) -> main_models.ModifyCuResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_cu_with_options(request, headers, runtime)

    async def modify_cu_async(
        self,
        request: main_models.ModifyCuRequest,
    ) -> main_models.ModifyCuResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_cu_with_options_async(request, headers, runtime)

    def modify_cu_pre_check_with_options(
        self,
        request: main_models.ModifyCuPreCheckRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyCuPreCheckResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyCuPreCheck',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyCuPreCheck',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyCuPreCheckResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_cu_pre_check_with_options_async(
        self,
        request: main_models.ModifyCuPreCheckRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyCuPreCheckResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyCuPreCheck',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyCuPreCheck',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyCuPreCheckResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_cu_pre_check(
        self,
        request: main_models.ModifyCuPreCheckRequest,
    ) -> main_models.ModifyCuPreCheckResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_cu_pre_check_with_options(request, headers, runtime)

    async def modify_cu_pre_check_async(
        self,
        request: main_models.ModifyCuPreCheckRequest,
    ) -> main_models.ModifyCuPreCheckResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_cu_pre_check_with_options_async(request, headers, runtime)

    def modify_disk_number_with_options(
        self,
        request: main_models.ModifyDiskNumberRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskNumberResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskNumber',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskNumber',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskNumberResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_disk_number_with_options_async(
        self,
        request: main_models.ModifyDiskNumberRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskNumberResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskNumber',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskNumber',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskNumberResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_disk_number(
        self,
        request: main_models.ModifyDiskNumberRequest,
    ) -> main_models.ModifyDiskNumberResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_disk_number_with_options(request, headers, runtime)

    async def modify_disk_number_async(
        self,
        request: main_models.ModifyDiskNumberRequest,
    ) -> main_models.ModifyDiskNumberResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_disk_number_with_options_async(request, headers, runtime)

    def modify_disk_performance_level_with_options(
        self,
        request: main_models.ModifyDiskPerformanceLevelRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskPerformanceLevelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskPerformanceLevel',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskPerformanceLevel',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskPerformanceLevelResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_disk_performance_level_with_options_async(
        self,
        request: main_models.ModifyDiskPerformanceLevelRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskPerformanceLevelResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskPerformanceLevel',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskPerformanceLevel',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskPerformanceLevelResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_disk_performance_level(
        self,
        request: main_models.ModifyDiskPerformanceLevelRequest,
    ) -> main_models.ModifyDiskPerformanceLevelResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_disk_performance_level_with_options(request, headers, runtime)

    async def modify_disk_performance_level_async(
        self,
        request: main_models.ModifyDiskPerformanceLevelRequest,
    ) -> main_models.ModifyDiskPerformanceLevelResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_disk_performance_level_with_options_async(request, headers, runtime)

    def modify_disk_size_with_options(
        self,
        request: main_models.ModifyDiskSizeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskSizeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskSize',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskSize',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskSizeResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_disk_size_with_options_async(
        self,
        request: main_models.ModifyDiskSizeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskSizeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskSize',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskSize',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskSizeResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_disk_size(
        self,
        request: main_models.ModifyDiskSizeRequest,
    ) -> main_models.ModifyDiskSizeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_disk_size_with_options(request, headers, runtime)

    async def modify_disk_size_async(
        self,
        request: main_models.ModifyDiskSizeRequest,
    ) -> main_models.ModifyDiskSizeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_disk_size_with_options_async(request, headers, runtime)

    def modify_disk_type_with_options(
        self,
        request: main_models.ModifyDiskTypeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskTypeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target_disk_type):
            query['TargetDiskType'] = request.target_disk_type
        if not DaraCore.is_null(request.target_performance_level):
            query['TargetPerformanceLevel'] = request.target_performance_level
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskType',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskType',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskTypeResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_disk_type_with_options_async(
        self,
        request: main_models.ModifyDiskTypeRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyDiskTypeResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target_disk_type):
            query['TargetDiskType'] = request.target_disk_type
        if not DaraCore.is_null(request.target_performance_level):
            query['TargetPerformanceLevel'] = request.target_performance_level
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyDiskType',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyDiskType',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyDiskTypeResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_disk_type(
        self,
        request: main_models.ModifyDiskTypeRequest,
    ) -> main_models.ModifyDiskTypeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_disk_type_with_options(request, headers, runtime)

    async def modify_disk_type_async(
        self,
        request: main_models.ModifyDiskTypeRequest,
    ) -> main_models.ModifyDiskTypeResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_disk_type_with_options_async(request, headers, runtime)

    def modify_node_number_with_options(
        self,
        request: main_models.ModifyNodeNumberRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyNodeNumberResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.parallelism):
            query['Parallelism'] = request.parallelism
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        if not DaraCore.is_null(request.termination_grace_period_seconds):
            query['TerminationGracePeriodSeconds'] = request.termination_grace_period_seconds
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyNodeNumber',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyNodeNumber',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyNodeNumberResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_node_number_with_options_async(
        self,
        request: main_models.ModifyNodeNumberRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyNodeNumberResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.parallelism):
            query['Parallelism'] = request.parallelism
        if not DaraCore.is_null(request.promotion_option_no):
            query['PromotionOptionNo'] = request.promotion_option_no
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        if not DaraCore.is_null(request.termination_grace_period_seconds):
            query['TerminationGracePeriodSeconds'] = request.termination_grace_period_seconds
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyNodeNumber',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyNodeNumber',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyNodeNumberResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_node_number(
        self,
        request: main_models.ModifyNodeNumberRequest,
    ) -> main_models.ModifyNodeNumberResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_node_number_with_options(request, headers, runtime)

    async def modify_node_number_async(
        self,
        request: main_models.ModifyNodeNumberRequest,
    ) -> main_models.ModifyNodeNumberResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_node_number_with_options_async(request, headers, runtime)

    def modify_node_number_pre_check_with_options(
        self,
        request: main_models.ModifyNodeNumberPreCheckRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyNodeNumberPreCheckResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyNodeNumberPreCheck',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyNodeNumberPreCheck',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyNodeNumberPreCheckResponse(),
            self.call_api(params, req, runtime)
        )

    async def modify_node_number_pre_check_with_options_async(
        self,
        request: main_models.ModifyNodeNumberPreCheckRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ModifyNodeNumberPreCheckResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        if not DaraCore.is_null(request.target):
            query['Target'] = request.target
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ModifyNodeNumberPreCheck',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/resourceChange/modifyNodeNumberPreCheck',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ModifyNodeNumberPreCheckResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def modify_node_number_pre_check(
        self,
        request: main_models.ModifyNodeNumberPreCheckRequest,
    ) -> main_models.ModifyNodeNumberPreCheckResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.modify_node_number_pre_check_with_options(request, headers, runtime)

    async def modify_node_number_pre_check_async(
        self,
        request: main_models.ModifyNodeNumberPreCheckRequest,
    ) -> main_models.ModifyNodeNumberPreCheckResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.modify_node_number_pre_check_with_options_async(request, headers, runtime)

    def query_upgradable_versions_with_options(
        self,
        request: main_models.QueryUpgradableVersionsRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.QueryUpgradableVersionsResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.minor):
            query['Minor'] = request.minor
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'QueryUpgradableVersions',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/queryUpgradableVersions',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.QueryUpgradableVersionsResponse(),
            self.call_api(params, req, runtime)
        )

    async def query_upgradable_versions_with_options_async(
        self,
        request: main_models.QueryUpgradableVersionsRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.QueryUpgradableVersionsResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.minor):
            query['Minor'] = request.minor
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'QueryUpgradableVersions',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/queryUpgradableVersions',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.QueryUpgradableVersionsResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def query_upgradable_versions(
        self,
        request: main_models.QueryUpgradableVersionsRequest,
    ) -> main_models.QueryUpgradableVersionsResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.query_upgradable_versions_with_options(request, headers, runtime)

    async def query_upgradable_versions_async(
        self,
        request: main_models.QueryUpgradableVersionsRequest,
    ) -> main_models.QueryUpgradableVersionsResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.query_upgradable_versions_with_options_async(request, headers, runtime)

    def release_instance_with_options(
        self,
        request: main_models.ReleaseInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ReleaseInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ReleaseInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/release',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ReleaseInstanceResponse(),
            self.call_api(params, req, runtime)
        )

    async def release_instance_with_options_async(
        self,
        request: main_models.ReleaseInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ReleaseInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ReleaseInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/release',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ReleaseInstanceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def release_instance(
        self,
        request: main_models.ReleaseInstanceRequest,
    ) -> main_models.ReleaseInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.release_instance_with_options(request, headers, runtime)

    async def release_instance_async(
        self,
        request: main_models.ReleaseInstanceRequest,
    ) -> main_models.ReleaseInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.release_instance_with_options_async(request, headers, runtime)

    def restart_instance_with_options(
        self,
        request: main_models.RestartInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RestartInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/restartCluster',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartInstanceResponse(),
            self.call_api(params, req, runtime)
        )

    async def restart_instance_with_options_async(
        self,
        request: main_models.RestartInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RestartInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/restartCluster',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartInstanceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def restart_instance(
        self,
        request: main_models.RestartInstanceRequest,
    ) -> main_models.RestartInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.restart_instance_with_options(request, headers, runtime)

    async def restart_instance_async(
        self,
        request: main_models.RestartInstanceRequest,
    ) -> main_models.RestartInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.restart_instance_with_options_async(request, headers, runtime)

    def restart_node_group_with_options(
        self,
        request: main_models.RestartNodeGroupRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartNodeGroupResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RestartNodeGroup',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/nodegroup/restart',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartNodeGroupResponse(),
            self.call_api(params, req, runtime)
        )

    async def restart_node_group_with_options_async(
        self,
        request: main_models.RestartNodeGroupRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartNodeGroupResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.node_group_id):
            query['NodeGroupId'] = request.node_group_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'RestartNodeGroup',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/nodegroup/restart',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartNodeGroupResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def restart_node_group(
        self,
        request: main_models.RestartNodeGroupRequest,
    ) -> main_models.RestartNodeGroupResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.restart_node_group_with_options(request, headers, runtime)

    async def restart_node_group_async(
        self,
        request: main_models.RestartNodeGroupRequest,
    ) -> main_models.RestartNodeGroupResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.restart_node_group_with_options_async(request, headers, runtime)

    def restart_nodes_with_options(
        self,
        request: main_models.RestartNodesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartNodesResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        body = {}
        if not DaraCore.is_null(request.restart_node_groups):
            body['RestartNodeGroups'] = request.restart_node_groups
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'RestartNodes',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/restart/restart',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartNodesResponse(),
            self.call_api(params, req, runtime)
        )

    async def restart_nodes_with_options_async(
        self,
        request: main_models.RestartNodesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestartNodesResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        body = {}
        if not DaraCore.is_null(request.restart_node_groups):
            body['RestartNodeGroups'] = request.restart_node_groups
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query),
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'RestartNodes',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/restart/restart',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestartNodesResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def restart_nodes(
        self,
        request: main_models.RestartNodesRequest,
    ) -> main_models.RestartNodesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.restart_nodes_with_options(request, headers, runtime)

    async def restart_nodes_async(
        self,
        request: main_models.RestartNodesRequest,
    ) -> main_models.RestartNodesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.restart_nodes_with_options_async(request, headers, runtime)

    def restore_instance_with_options(
        self,
        request: main_models.RestoreInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestoreInstanceResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.admin_password):
            body['AdminPassword'] = request.admin_password
        if not DaraCore.is_null(request.auto_renew):
            body['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.backup_task_id):
            body['BackupTaskId'] = request.backup_task_id
        if not DaraCore.is_null(request.duration):
            body['Duration'] = request.duration
        if not DaraCore.is_null(request.instance_name):
            body['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.pay_type):
            body['PayType'] = request.pay_type
        if not DaraCore.is_null(request.pricing_cycle):
            body['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            body['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.tags):
            body['Tags'] = request.tags
        if not DaraCore.is_null(request.v_switches):
            body['VSwitches'] = request.v_switches
        if not DaraCore.is_null(request.vpc_id):
            body['VpcId'] = request.vpc_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'RestoreInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/restore/restoreInstance',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestoreInstanceResponse(),
            self.call_api(params, req, runtime)
        )

    async def restore_instance_with_options_async(
        self,
        request: main_models.RestoreInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.RestoreInstanceResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.admin_password):
            body['AdminPassword'] = request.admin_password
        if not DaraCore.is_null(request.auto_renew):
            body['AutoRenew'] = request.auto_renew
        if not DaraCore.is_null(request.backup_task_id):
            body['BackupTaskId'] = request.backup_task_id
        if not DaraCore.is_null(request.duration):
            body['Duration'] = request.duration
        if not DaraCore.is_null(request.instance_name):
            body['InstanceName'] = request.instance_name
        if not DaraCore.is_null(request.pay_type):
            body['PayType'] = request.pay_type
        if not DaraCore.is_null(request.pricing_cycle):
            body['PricingCycle'] = request.pricing_cycle
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_group_id):
            body['ResourceGroupId'] = request.resource_group_id
        if not DaraCore.is_null(request.tags):
            body['Tags'] = request.tags
        if not DaraCore.is_null(request.v_switches):
            body['VSwitches'] = request.v_switches
        if not DaraCore.is_null(request.vpc_id):
            body['VpcId'] = request.vpc_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'RestoreInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/restore/restoreInstance',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.RestoreInstanceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def restore_instance(
        self,
        request: main_models.RestoreInstanceRequest,
    ) -> main_models.RestoreInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.restore_instance_with_options(request, headers, runtime)

    async def restore_instance_async(
        self,
        request: main_models.RestoreInstanceRequest,
    ) -> main_models.RestoreInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.restore_instance_with_options_async(request, headers, runtime)

    def resume_instance_with_options(
        self,
        request: main_models.ResumeInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ResumeInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ResumeInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/lifecycle/resumeInstance',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ResumeInstanceResponse(),
            self.call_api(params, req, runtime)
        )

    async def resume_instance_with_options_async(
        self,
        request: main_models.ResumeInstanceRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.ResumeInstanceResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'ResumeInstance',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/lifecycle/resumeInstance',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.ResumeInstanceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def resume_instance(
        self,
        request: main_models.ResumeInstanceRequest,
    ) -> main_models.ResumeInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.resume_instance_with_options(request, headers, runtime)

    async def resume_instance_async(
        self,
        request: main_models.ResumeInstanceRequest,
    ) -> main_models.ResumeInstanceResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.resume_instance_with_options_async(request, headers, runtime)

    def tag_resources_with_options(
        self,
        request: main_models.TagResourcesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.TagResourcesResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_id):
            body['ResourceId'] = request.resource_id
        if not DaraCore.is_null(request.resource_type):
            body['ResourceType'] = request.resource_type
        if not DaraCore.is_null(request.tag):
            body['Tag'] = request.tag
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'TagResources',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/tags',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TagResourcesResponse(),
            self.call_api(params, req, runtime)
        )

    async def tag_resources_with_options_async(
        self,
        request: main_models.TagResourcesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.TagResourcesResponse:
        request.validate()
        body = {}
        if not DaraCore.is_null(request.region_id):
            body['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_id):
            body['ResourceId'] = request.resource_id
        if not DaraCore.is_null(request.resource_type):
            body['ResourceType'] = request.resource_type
        if not DaraCore.is_null(request.tag):
            body['Tag'] = request.tag
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            body = Utils.parse_to_map(body)
        )
        params = open_api_util_models.Params(
            action = 'TagResources',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/tags',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TagResourcesResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def tag_resources(
        self,
        request: main_models.TagResourcesRequest,
    ) -> main_models.TagResourcesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.tag_resources_with_options(request, headers, runtime)

    async def tag_resources_async(
        self,
        request: main_models.TagResourcesRequest,
    ) -> main_models.TagResourcesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.tag_resources_with_options_async(request, headers, runtime)

    def toggle_public_slb_with_options(
        self,
        request: main_models.TogglePublicSlbRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.TogglePublicSlbResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.enable_public_slb):
            query['EnablePublicSlb'] = request.enable_public_slb
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TogglePublicSlb',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/togglePublicSlb',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TogglePublicSlbResponse(),
            self.call_api(params, req, runtime)
        )

    async def toggle_public_slb_with_options_async(
        self,
        request: main_models.TogglePublicSlbRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.TogglePublicSlbResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.enable_public_slb):
            query['EnablePublicSlb'] = request.enable_public_slb
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'TogglePublicSlb',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/togglePublicSlb',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.TogglePublicSlbResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def toggle_public_slb(
        self,
        request: main_models.TogglePublicSlbRequest,
    ) -> main_models.TogglePublicSlbResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.toggle_public_slb_with_options(request, headers, runtime)

    async def toggle_public_slb_async(
        self,
        request: main_models.TogglePublicSlbRequest,
    ) -> main_models.TogglePublicSlbResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.toggle_public_slb_with_options_async(request, headers, runtime)

    def un_tag_resources_with_options(
        self,
        tmp_req: main_models.UnTagResourcesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UnTagResourcesResponse:
        tmp_req.validate()
        request = main_models.UnTagResourcesShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.resource_id):
            request.resource_id_shrink = Utils.array_to_string_with_specified_style(tmp_req.resource_id, 'ResourceId', 'json')
        if not DaraCore.is_null(tmp_req.tag_key):
            request.tag_key_shrink = Utils.array_to_string_with_specified_style(tmp_req.tag_key, 'TagKey', 'json')
        query = {}
        if not DaraCore.is_null(request.all):
            query['All'] = request.all
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_id_shrink):
            query['ResourceId'] = request.resource_id_shrink
        if not DaraCore.is_null(request.resource_type):
            query['ResourceType'] = request.resource_type
        if not DaraCore.is_null(request.tag_key_shrink):
            query['TagKey'] = request.tag_key_shrink
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UnTagResources',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/tags',
            method = 'DELETE',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UnTagResourcesResponse(),
            self.call_api(params, req, runtime)
        )

    async def un_tag_resources_with_options_async(
        self,
        tmp_req: main_models.UnTagResourcesRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UnTagResourcesResponse:
        tmp_req.validate()
        request = main_models.UnTagResourcesShrinkRequest()
        Utils.convert(tmp_req, request)
        if not DaraCore.is_null(tmp_req.resource_id):
            request.resource_id_shrink = Utils.array_to_string_with_specified_style(tmp_req.resource_id, 'ResourceId', 'json')
        if not DaraCore.is_null(tmp_req.tag_key):
            request.tag_key_shrink = Utils.array_to_string_with_specified_style(tmp_req.tag_key, 'TagKey', 'json')
        query = {}
        if not DaraCore.is_null(request.all):
            query['All'] = request.all
        if not DaraCore.is_null(request.region_id):
            query['RegionId'] = request.region_id
        if not DaraCore.is_null(request.resource_id_shrink):
            query['ResourceId'] = request.resource_id_shrink
        if not DaraCore.is_null(request.resource_type):
            query['ResourceType'] = request.resource_type
        if not DaraCore.is_null(request.tag_key_shrink):
            query['TagKey'] = request.tag_key_shrink
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UnTagResources',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/tags',
            method = 'DELETE',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UnTagResourcesResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def un_tag_resources(
        self,
        request: main_models.UnTagResourcesRequest,
    ) -> main_models.UnTagResourcesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.un_tag_resources_with_options(request, headers, runtime)

    async def un_tag_resources_async(
        self,
        request: main_models.UnTagResourcesRequest,
    ) -> main_models.UnTagResourcesResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.un_tag_resources_with_options_async(request, headers, runtime)

    def update_gateway_with_options(
        self,
        request: main_models.UpdateGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpdateGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fe_node_number):
            query['FeNodeNumber'] = request.fe_node_number
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.gateway_name):
            query['GatewayName'] = request.gateway_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/update',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateGatewayResponse(),
            self.call_api(params, req, runtime)
        )

    async def update_gateway_with_options_async(
        self,
        request: main_models.UpdateGatewayRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpdateGatewayResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fe_node_number):
            query['FeNodeNumber'] = request.fe_node_number
        if not DaraCore.is_null(request.gateway_id):
            query['GatewayId'] = request.gateway_id
        if not DaraCore.is_null(request.gateway_name):
            query['GatewayName'] = request.gateway_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateGateway',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/gateway/update',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateGatewayResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def update_gateway(
        self,
        request: main_models.UpdateGatewayRequest,
    ) -> main_models.UpdateGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.update_gateway_with_options(request, headers, runtime)

    async def update_gateway_async(
        self,
        request: main_models.UpdateGatewayRequest,
    ) -> main_models.UpdateGatewayResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.update_gateway_with_options_async(request, headers, runtime)

    def update_instance_name_with_options(
        self,
        request: main_models.UpdateInstanceNameRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpdateInstanceNameResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.cluster_name):
            query['ClusterName'] = request.cluster_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateInstanceName',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/update_name',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateInstanceNameResponse(),
            self.call_api(params, req, runtime)
        )

    async def update_instance_name_with_options_async(
        self,
        request: main_models.UpdateInstanceNameRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpdateInstanceNameResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.cluster_name):
            query['ClusterName'] = request.cluster_name
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpdateInstanceName',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/cluster/update_name',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpdateInstanceNameResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def update_instance_name(
        self,
        request: main_models.UpdateInstanceNameRequest,
    ) -> main_models.UpdateInstanceNameResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.update_instance_name_with_options(request, headers, runtime)

    async def update_instance_name_async(
        self,
        request: main_models.UpdateInstanceNameRequest,
    ) -> main_models.UpdateInstanceNameResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.update_instance_name_with_options_async(request, headers, runtime)

    def upgrade_version_with_options(
        self,
        request: main_models.UpgradeVersionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpgradeVersionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.minor):
            query['Minor'] = request.minor
        if not DaraCore.is_null(request.target_version):
            query['TargetVersion'] = request.target_version
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpgradeVersion',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/upgradeVersion',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpgradeVersionResponse(),
            self.call_api(params, req, runtime)
        )

    async def upgrade_version_with_options_async(
        self,
        request: main_models.UpgradeVersionRequest,
        headers: Dict[str, str],
        runtime: RuntimeOptions,
    ) -> main_models.UpgradeVersionResponse:
        request.validate()
        query = {}
        if not DaraCore.is_null(request.fast_mode):
            query['FastMode'] = request.fast_mode
        if not DaraCore.is_null(request.instance_id):
            query['InstanceId'] = request.instance_id
        if not DaraCore.is_null(request.minor):
            query['Minor'] = request.minor
        if not DaraCore.is_null(request.target_version):
            query['TargetVersion'] = request.target_version
        req = open_api_util_models.OpenApiRequest(
            headers = headers,
            query = Utils.query(query)
        )
        params = open_api_util_models.Params(
            action = 'UpgradeVersion',
            version = '2022-10-19',
            protocol = 'HTTPS',
            pathname = f'/webapi/starrocks/upgradeVersion',
            method = 'POST',
            auth_type = 'AK',
            style = 'ROA',
            req_body_type = 'json',
            body_type = 'json'
        )
        return DaraCore.from_map(
            main_models.UpgradeVersionResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def upgrade_version(
        self,
        request: main_models.UpgradeVersionRequest,
    ) -> main_models.UpgradeVersionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return self.upgrade_version_with_options(request, headers, runtime)

    async def upgrade_version_async(
        self,
        request: main_models.UpgradeVersionRequest,
    ) -> main_models.UpgradeVersionResponse:
        runtime = RuntimeOptions()
        headers = {}
        return await self.upgrade_version_with_options_async(request, headers, runtime)



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class TogglePublicSlbRequest(DaraModel):
    def __init__(
        self,
        enable_public_slb: bool = None,
        gateway_id: str = None,
        instance_id: str = None,
    ):
        self.enable_public_slb = enable_public_slb
        self.gateway_id = gateway_id
        self.instance_id = instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable_public_slb is not None:
            result['EnablePublicSlb'] = self.enable_public_slb

        if self.gateway_id is not None:
            result['GatewayId'] = self.gateway_id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EnablePublicSlb') is not None:
            self.enable_public_slb = m.get('EnablePublicSlb')

        if m.get('GatewayId') is not None:
            self.gateway_id = m.get('GatewayId')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class InstanceConfigDto(DaraModel):
    def __init__(
        self,
        config_key: str = None,
        config_type: str = None,
        config_value: str = None,
        node_group_id: str = None,
    ):
        self.config_key = config_key
        self.config_type = config_type
        self.config_value = config_value
        self.node_group_id = node_group_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_key is not None:
            result['configKey'] = self.config_key

        if self.config_type is not None:
            result['configType'] = self.config_type

        if self.config_value is not None:
            result['configValue'] = self.config_value

        if self.node_group_id is not None:
            result['nodeGroupId'] = self.node_group_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('configKey') is not None:
            self.config_key = m.get('configKey')

        if m.get('configType') is not None:
            self.config_type = m.get('configType')

        if m.get('configValue') is not None:
            self.config_value = m.get('configValue')

        if m.get('nodeGroupId') is not None:
            self.node_group_id = m.get('nodeGroupId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ResourceSpec(DaraModel):
    def __init__(
        self,
        cu: int = None,
        disk_number: int = None,
        local_storage_instance_type: str = None,
        node_number: int = None,
        spec_type: str = None,
        storage_performance_level: str = None,
        storage_size: int = None,
    ):
        # The number of CUs. A compute unit (CU) is the basic metering unit of a service. 1 CU = 1 CPU core + 4 GiB of memory.
        self.cu = cu
        # The number of disk blocks.
        self.disk_number = disk_number
        # Local SSD Instance Specification for the node group. This parameter is applicable only when the node group is based on ECS instances and the SpecType is set to \\"Local SSD / Large-capacity Storage\\"
        self.local_storage_instance_type = local_storage_instance_type
        # The number of nodes.
        self.node_number = node_number
        # The type of the node group. The following types are included:
        # 
        # *   standard, Standard Edition, ECS + cloud disk.
        # *   localSSD , local SSD.
        # *   bigData, which stores large specifications.
        self.spec_type = spec_type
        # The performance level of the disks. Valid values:
        # 
        # *   PL0: A single disk can achieve up to 10,000 random read/write IOPS.
        # *   PL1: A single disk can achieve up to 50,000 random read/write IOPS.
        # *   PL2: A single disk can achieve up to 100,000 random read/write IOPS.
        # *   PL3: A single disk can achieve up to 1 million random read/write IOPS.
        self.storage_performance_level = storage_performance_level
        # The storage size.
        self.storage_size = storage_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cu is not None:
            result['cu'] = self.cu

        if self.disk_number is not None:
            result['diskNumber'] = self.disk_number

        if self.local_storage_instance_type is not None:
            result['localStorageInstanceType'] = self.local_storage_instance_type

        if self.node_number is not None:
            result['nodeNumber'] = self.node_number

        if self.spec_type is not None:
            result['specType'] = self.spec_type

        if self.storage_performance_level is not None:
            result['storagePerformanceLevel'] = self.storage_performance_level

        if self.storage_size is not None:
            result['storageSize'] = self.storage_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cu') is not None:
            self.cu = m.get('cu')

        if m.get('diskNumber') is not None:
            self.disk_number = m.get('diskNumber')

        if m.get('localStorageInstanceType') is not None:
            self.local_storage_instance_type = m.get('localStorageInstanceType')

        if m.get('nodeNumber') is not None:
            self.node_number = m.get('nodeNumber')

        if m.get('specType') is not None:
            self.spec_type = m.get('specType')

        if m.get('storagePerformanceLevel') is not None:
            self.storage_performance_level = m.get('storagePerformanceLevel')

        if m.get('storageSize') is not None:
            self.storage_size = m.get('storageSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UnTagResourcesShrinkRequest(DaraModel):
    def __init__(
        self,
        all: bool = None,
        region_id: str = None,
        resource_id_shrink: str = None,
        resource_type: str = None,
        tag_key_shrink: str = None,
    ):
        self.all = all
        # This parameter is required.
        self.region_id = region_id
        # This parameter is required.
        self.resource_id_shrink = resource_id_shrink
        # This parameter is required.
        self.resource_type = resource_type
        self.tag_key_shrink = tag_key_shrink

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.all is not None:
            result['All'] = self.all

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_id_shrink is not None:
            result['ResourceId'] = self.resource_id_shrink

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        if self.tag_key_shrink is not None:
            result['TagKey'] = self.tag_key_shrink

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('All') is not None:
            self.all = m.get('All')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceId') is not None:
            self.resource_id_shrink = m.get('ResourceId')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        if m.get('TagKey') is not None:
            self.tag_key_shrink = m.get('TagKey')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyChargeTypeRequest(DaraModel):
    def __init__(
        self,
        auto_renew: bool = None,
        billing_instance_ids: str = None,
        duration: str = None,
        instance_id: str = None,
        pricing_cycle: str = None,
        promotion_option_no: str = None,
    ):
        self.auto_renew = auto_renew
        self.billing_instance_ids = billing_instance_ids
        self.duration = duration
        self.instance_id = instance_id
        self.pricing_cycle = pricing_cycle
        self.promotion_option_no = promotion_option_no

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_renew is not None:
            result['AutoRenew'] = self.auto_renew

        if self.billing_instance_ids is not None:
            result['BillingInstanceIds'] = self.billing_instance_ids

        if self.duration is not None:
            result['Duration'] = self.duration

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.pricing_cycle is not None:
            result['PricingCycle'] = self.pricing_cycle

        if self.promotion_option_no is not None:
            result['PromotionOptionNo'] = self.promotion_option_no

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoRenew') is not None:
            self.auto_renew = m.get('AutoRenew')

        if m.get('BillingInstanceIds') is not None:
            self.billing_instance_ids = m.get('BillingInstanceIds')

        if m.get('Duration') is not None:
            self.duration = m.get('Duration')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('PricingCycle') is not None:
            self.pricing_cycle = m.get('PricingCycle')

        if m.get('PromotionOptionNo') is not None:
            self.promotion_option_no = m.get('PromotionOptionNo')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class RestoreInstanceRequest(DaraModel):
    def __init__(
        self,
        admin_password: str = None,
        auto_renew: bool = None,
        backup_task_id: str = None,
        duration: int = None,
        instance_name: str = None,
        pay_type: str = None,
        pricing_cycle: str = None,
        region_id: str = None,
        resource_group_id: str = None,
        tags: List[main_models.RestoreInstanceRequestTags] = None,
        v_switches: List[main_models.RestoreInstanceRequestVSwitches] = None,
        vpc_id: str = None,
    ):
        self.admin_password = admin_password
        self.auto_renew = auto_renew
        self.backup_task_id = backup_task_id
        self.duration = duration
        self.instance_name = instance_name
        self.pay_type = pay_type
        self.pricing_cycle = pricing_cycle
        self.region_id = region_id
        self.resource_group_id = resource_group_id
        self.tags = tags
        self.v_switches = v_switches
        # vpc ID
        self.vpc_id = vpc_id

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()
        if self.v_switches:
            for v1 in self.v_switches:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.admin_password is not None:
            result['AdminPassword'] = self.admin_password

        if self.auto_renew is not None:
            result['AutoRenew'] = self.auto_renew

        if self.backup_task_id is not None:
            result['BackupTaskId'] = self.backup_task_id

        if self.duration is not None:
            result['Duration'] = self.duration

        if self.instance_name is not None:
            result['InstanceName'] = self.instance_name

        if self.pay_type is not None:
            result['PayType'] = self.pay_type

        if self.pricing_cycle is not None:
            result['PricingCycle'] = self.pricing_cycle

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        result['VSwitches'] = []
        if self.v_switches is not None:
            for k1 in self.v_switches:
                result['VSwitches'].append(k1.to_map() if k1 else None)

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AdminPassword') is not None:
            self.admin_password = m.get('AdminPassword')

        if m.get('AutoRenew') is not None:
            self.auto_renew = m.get('AutoRenew')

        if m.get('BackupTaskId') is not None:
            self.backup_task_id = m.get('BackupTaskId')

        if m.get('Duration') is not None:
            self.duration = m.get('Duration')

        if m.get('InstanceName') is not None:
            self.instance_name = m.get('InstanceName')

        if m.get('PayType') is not None:
            self.pay_type = m.get('PayType')

        if m.get('PricingCycle') is not None:
            self.pricing_cycle = m.get('PricingCycle')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.RestoreInstanceRequestTags()
                self.tags.append(temp_model.from_map(k1))

        self.v_switches = []
        if m.get('VSwitches') is not None:
            for k1 in m.get('VSwitches'):
                temp_model = main_models.RestoreInstanceRequestVSwitches()
                self.v_switches.append(temp_model.from_map(k1))

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        return self

class RestoreInstanceRequestVSwitches(DaraModel):
    def __init__(
        self,
        vsw_id: str = None,
        zone_id: str = None,
    ):
        self.vsw_id = vsw_id
        self.zone_id = zone_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.vsw_id is not None:
            result['VswId'] = self.vsw_id

        if self.zone_id is not None:
            result['ZoneId'] = self.zone_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('VswId') is not None:
            self.vsw_id = m.get('VswId')

        if m.get('ZoneId') is not None:
            self.zone_id = m.get('ZoneId')

        return self

class RestoreInstanceRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['key'] = self.key

        if self.value is not None:
            result['value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('value') is not None:
            self.value = m.get('value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class DescribeInstancesRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        instance_name: str = None,
        instance_status: str = None,
        page_number: int = None,
        page_size: int = None,
        region_id: str = None,
        resource_group_id: str = None,
        tag: List[main_models.DescribeInstancesRequestTag] = None,
    ):
        self.instance_id = instance_id
        self.instance_name = instance_name
        self.instance_status = instance_status
        self.page_number = page_number
        self.page_size = page_size
        self.region_id = region_id
        self.resource_group_id = resource_group_id
        self.tag = tag

    def validate(self):
        if self.tag:
            for v1 in self.tag:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.instance_name is not None:
            result['InstanceName'] = self.instance_name

        if self.instance_status is not None:
            result['InstanceStatus'] = self.instance_status

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        result['Tag'] = []
        if self.tag is not None:
            for k1 in self.tag:
                result['Tag'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('InstanceName') is not None:
            self.instance_name = m.get('InstanceName')

        if m.get('InstanceStatus') is not None:
            self.instance_status = m.get('InstanceStatus')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        self.tag = []
        if m.get('Tag') is not None:
            for k1 in m.get('Tag'):
                temp_model = main_models.DescribeInstancesRequestTag()
                self.tag.append(temp_model.from_map(k1))

        return self

class DescribeInstancesRequestTag(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_starrocks20221019 import models as main_models
from darabonba.model import DaraModel

class ListGatewayResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.ListGatewayResponseBodyData] = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.err_code is not None:
            result['ErrCode'] = self.err_code

        if self.err_message is not None:
            result['ErrMessage'] = self.err_message

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListGatewayResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('ErrCode') is not None:
            self.err_code = m.get('ErrCode')

        if m.get('ErrMessage') is not None:
            self.err_message = m.get('ErrMessage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class ListGatewayResponseBodyData(DaraModel):
    def __init__(
        self,
        enable_public_net: bool = None,
        fe_node_number: int = None,
        gateway_id: str = None,
        gateway_name: str = None,
        gateway_type: str = None,
        internal_domain: str = None,
        internal_slb_id: str = None,
        privatezone_id: str = None,
        public_domain: str = None,
        public_slb_acl_id: str = None,
        public_slb_id: str = None,
    ):
        self.enable_public_net = enable_public_net
        self.fe_node_number = fe_node_number
        self.gateway_id = gateway_id
        self.gateway_name = gateway_name
        self.gateway_type = gateway_type
        self.internal_domain = internal_domain
        self.internal_slb_id = internal_slb_id
        # PrivatezoneId
        self.privatezone_id = privatezone_id
        self.public_domain = public_domain
        self.public_slb_acl_id = public_slb_acl_id
        self.public_slb_id = public_slb_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable_public_net is not None:
            result['EnablePublicNet'] = self.enable_public_net

        if self.fe_node_number is not None:
            result['FeNodeNumber'] = self.fe_node_number

        if self.gateway_id is not None:
            result['GatewayId'] = self.gateway_id

        if self.gateway_name is not None:
            result['GatewayName'] = self.gateway_name

        if self.gateway_type is not None:
            result['GatewayType'] = self.gateway_type

        if self.internal_domain is not None:
            result['InternalDomain'] = self.internal_domain

        if self.internal_slb_id is not None:
            result['InternalSlbId'] = self.internal_slb_id

        if self.privatezone_id is not None:
            result['PrivatezoneId'] = self.privatezone_id

        if self.public_domain is not None:
            result['PublicDomain'] = self.public_domain

        if self.public_slb_acl_id is not None:
            result['PublicSlbAclId'] = self.public_slb_acl_id

        if self.public_slb_id is not None:
            result['PublicSlbId'] = self.public_slb_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EnablePublicNet') is not None:
            self.enable_public_net = m.get('EnablePublicNet')

        if m.get('FeNodeNumber') is not None:
            self.fe_node_number = m.get('FeNodeNumber')

        if m.get('GatewayId') is not None:
            self.gateway_id = m.get('GatewayId')

        if m.get('GatewayName') is not None:
            self.gateway_name = m.get('GatewayName')

        if m.get('GatewayType') is not None:
            self.gateway_type = m.get('GatewayType')

        if m.get('InternalDomain') is not None:
            self.internal_domain = m.get('InternalDomain')

        if m.get('InternalSlbId') is not None:
            self.internal_slb_id = m.get('InternalSlbId')

        if m.get('PrivatezoneId') is not None:
            self.privatezone_id = m.get('PrivatezoneId')

        if m.get('PublicDomain') is not None:
            self.public_domain = m.get('PublicDomain')

        if m.get('PublicSlbAclId') is not None:
            self.public_slb_acl_id = m.get('PublicSlbAclId')

        if m.get('PublicSlbId') is not None:
            self.public_slb_id = m.get('PublicSlbId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class DescribeNodeGroupsRequest(DaraModel):
    def __init__(
        self,
        cluster_id: str = None,
        page_number: int = None,
        page_size: int = None,
        component_type: str = None,
        instance_id: str = None,
        node_group_ids: List[str] = None,
        node_group_name: str = None,
        status: str = None,
    ):
        self.cluster_id = cluster_id
        self.page_number = page_number
        self.page_size = page_size
        self.component_type = component_type
        self.instance_id = instance_id
        self.node_group_ids = node_group_ids
        self.node_group_name = node_group_name
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cluster_id is not None:
            result['ClusterId'] = self.cluster_id

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.component_type is not None:
            result['componentType'] = self.component_type

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.node_group_ids is not None:
            result['nodeGroupIds'] = self.node_group_ids

        if self.node_group_name is not None:
            result['nodeGroupName'] = self.node_group_name

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ClusterId') is not None:
            self.cluster_id = m.get('ClusterId')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('componentType') is not None:
            self.component_type = m.get('componentType')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('nodeGroupIds') is not None:
            self.node_group_ids = m.get('nodeGroupIds')

        if m.get('nodeGroupName') is not None:
            self.node_group_name = m.get('nodeGroupName')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpgradeVersionResponseBody(DaraModel):
    def __init__(
        self,
        access_denied_detail: str = None,
        data: bool = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The detailed information about the failed permission verification.
        self.access_denied_detail = access_denied_detail
        # The returned data.
        self.data = data
        # The error code.
        self.err_code = err_code
        # The error message.
        self.err_message = err_message
        # The HTTP status code.
        self.http_status_code = http_status_code
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful.
        self.success = success

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.access_denied_detail is not None:
            result['AccessDeniedDetail'] = self.access_denied_detail

        if self.data is not None:
            result['Data'] = self.data

        if self.err_code is not None:
            result['ErrCode'] = self.err_code

        if self.err_message is not None:
            result['ErrMessage'] = self.err_message

        if self.http_status_code is not None:
            result['HttpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessDeniedDetail') is not None:
            self.access_denied_detail = m.get('AccessDeniedDetail')

        if m.get('Data') is not None:
            self.data = m.get('Data')

        if m.get('ErrCode') is not None:
            self.err_code = m.get('ErrCode')

        if m.get('ErrMessage') is not None:
            self.err_message = m.get('ErrMessage')

        if m.get('HttpStatusCode') is not None:
            self.http_status_code = m.get('HttpStatusCode')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class EnableSSLConnectionRequest(DaraModel):
    def __init__(
        self,
        custom_sslcertificate: str = None,
        enable_custom: bool = None,
        instance_id: str = None,
        renewal: bool = None,
        ssl_key_password: str = None,
        ssl_keystore_password: str = None,
    ):
        self.custom_sslcertificate = custom_sslcertificate
        self.enable_custom = enable_custom
        self.instance_id = instance_id
        self.renewal = renewal
        self.ssl_key_password = ssl_key_password
        self.ssl_keystore_password = ssl_keystore_password

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.custom_sslcertificate is not None:
            result['CustomSSLCertificate'] = self.custom_sslcertificate

        if self.enable_custom is not None:
            result['EnableCustom'] = self.enable_custom

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.renewal is not None:
            result['Renewal'] = self.renewal

        if self.ssl_key_password is not None:
            result['SslKeyPassword'] = self.ssl_key_password

        if self.ssl_keystore_password is not None:
            result['SslKeystorePassword'] = self.ssl_keystore_password

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CustomSSLCertificate') is not None:
            self.custom_sslcertificate = m.get('CustomSSLCertificate')

        if m.get('EnableCustom') is not None:
            self.enable_custom = m.get('EnableCustom')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Renewal') is not None:
            self.renewal = m.get('Renewal')

        if m.get('SslKeyPassword') is not None:
            self.ssl_key_password = m.get('SslKeyPassword')

        if m.get('SslKeystorePassword') is not None:
            self.ssl_keystore_password = m.get('SslKeystorePassword')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpgradeVersionRequest(DaraModel):
    def __init__(
        self,
        fast_mode: bool = None,
        instance_id: str = None,
        minor: bool = None,
        target_version: str = None,
    ):
        self.fast_mode = fast_mode
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # Specifies whether the minor version is upgraded. Default value: true. Valid values:
        # 
        # *   true: The minor version is upgraded.
        # *   false: The major version is upgraded.
        self.minor = minor
        # The version to which you want to upgrade.
        # 
        # This parameter is required.
        self.target_version = target_version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.fast_mode is not None:
            result['FastMode'] = self.fast_mode

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.minor is not None:
            result['Minor'] = self.minor

        if self.target_version is not None:
            result['TargetVersion'] = self.target_version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FastMode') is not None:
            self.fast_mode = m.get('FastMode')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Minor') is not None:
            self.minor = m.get('Minor')

        if m.get('TargetVersion') is not None:
            self.target_version = m.get('TargetVersion')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModifyDiskPerformanceLevelRequest(DaraModel):
    def __init__(
        self,
        instance_id: str = None,
        node_group_id: str = None,
        promotion_option_no: str = None,
        target: str = None,
    ):
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The warehouse ID.
        # 
        # This parameter is required.
        self.node_group_id = node_group_id
        self.promotion_option_no = promotion_option_no
        # The disk performance level to which you want to change.
        # 
        # Valid values:
        # 
        # *   pl0
        # *   pl1
        # *   pl2
        # *   pl3
        # 
        # This parameter is required.
        self.target = target

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_group_id is not None:
            result['NodeGroupId'] = self.node_group_id

        if self.promotion_option_no is not None:
            result['PromotionOptionNo'] = self.promotion_option_no

        if self.target is not None:
            result['Target'] = self.target

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeGroupId') is not None:
            self.node_group_id = m.get('NodeGroupId')

        if m.get('PromotionOptionNo') is not None:
            self.promotion_option_no = m.get('PromotionOptionNo')

        if m.get('Target') is not None:
            self.target = m.get('Target')

        return self

